@@ -18,13 +18,8 @@ import numpy as np
 #-------------------------------------------------------------------------
 # label, a,b,c,alpha, beta, gamma  in real space lattice, extinction rules label
 dict_Materials = {
-    "Al2O3_4temp": ["Al2O3_4temp", [4.759397,4.759397,12.9928,90.0,90.0,120.0], "167"],
-    "Al2O3_3temp": ["Al2O3_3temp", [4.762022894621087,4.762022894621087,12.9928,90.0,90.0,120.0], "167"],
-    "Al2O3_2temp": ["Al2O3_2temp", [4.759397,4.759397,12.9928,90.0,90.0,120.0], "167"],
-    "Al2O3_1temp": ["Al2O3_1temp", [4.789537587563778,4.789537587563778,13.080795536749589,90.0,90.0,120.0], "167"],
-    "Al2O3_750C": ["Al2O3_750C", [4.7867,4.7867,13.07257,90.0,90.0,120.0], "167"],
-    "Al2O3_0temp": ["Al2O3_0temp", [4.7867,4.7867,13.07257,90.0,90.0,120.0], "167"],
-    "ZrO2_1250": ["ZrO2_1250", [3.6,3.6,5.2,90.0,90,90], "137"],
+    "ZrO2_1250C": ["ZrO2_1250C", [3.6423954,3.6423954,5.28113,90.0,90,90], "h+k+l=2n"],
+    "ZrO2_1200C": ["ZrO2_1200C", [3.640666542,3.640666542,5.27828,90,90,90], "h+k+l=2n"],
     "alm": ["alm", [3.60500, 9.44500, 9.65300, 90, 90, 90], "no"],
     "Ag": ["Ag", [4.085, 4.085, 4.085, 90, 90, 90], "fcc"],  # confirmed by IM2NP
     "Al2O3": ["Al2O3", [4.785, 4.785, 12.991, 90, 90, 120], "Al2O3"],
@@ -68,7 +63,7 @@ dict_Materials = {
     "UO2": ["UO2", [5.47, 5.47, 5.47, 90, 90, 90], "fcc"],
     "ZrO2Y2O3": ["ZrO2Y2O3", [5.1378, 5.1378, 5.1378, 90, 90, 90], "fcc"],
     "ZrO2": ["ZrO2", [5.1505, 5.2116, 5.3173, 90, 99.23, 90], "VO2_mono"],
-    "ZrO2_1250C": ["ZrO2_1250C", [3.26, 3.26, 5.28, 90, 90, 90], "no"],
+    "ZrO2_SG": ["ZrO2_SG", [5.1505, 5.2116, 5.3173, 90, 99.23, 90], "14"],
     "ZrO2fake1": ["ZrO2fake1", [5.1505, 5.048116, 4.988933, 90, 99.23, 90], "VO2_mono"],
     "DIA": ["DIA", [5.0, 5.0, 5.0, 90, 90, 90], "dia", ],  #  small lattice Diamond like Structure
     "DIAs": ["DIAs", [3.56683, 3.56683, 3.56683, 90, 90, 90], "dia", ],  #  small lattice Diamond material Structure
@@ -116,8 +111,9 @@ dict_Materials = {
     "VO2M1": ["VO2M1", [5.75175, 4.52596, 5.38326, 90.0, 122.6148, 90.0], "VO2_mono", ],  # SG 14
     "VO2M2": ["VO2M2", [4.5546, 4.5546, 2.8514, 90.0, 90, 90.0], "no" ],  # SG 136 (87 deg Celsius)  Rutile
     "VO2R": ["VO2R", [4.5546, 4.5546, 2.8514, 90.0, 90, 90.0], "rutile"],  # SG 136 (87 deg Celsius)  Rutile
-    "ZnCuOCl": ["ZnCuOCl", [6.839, 6.839, 14.08, 90.0, 90, 120.0], "SG166"],
-    "ZnCuOCl_all": ["ZnCuOCl_all", [6.839, 6.839, 14.08, 90.0, 90, 120.0], "no"],
+    "ZnCuOCl": ["ZnCuOCl", [6.83972, 6.83972, 14.08845, 90.0, 90, 120.0], "SG166"],
+    "ZnCuOCl_all": ["ZnCuOCl_all", [6.83972, 6.83972, 14.08845, 90.0, 90, 120.0], "no"],
+    "ZnCuOCl_SG": ["ZnCuOCl_all", [6.83972, 6.83972, 14.08845, 90.0, 90, 120.0], "166"],
     "Al2TiO5_all": ["Al2TiO5_all", [3.60500,	9.44500,	9.65300, 90.0, 90, 90], "no"],
     "Al2TiO5": ["Al2TiO5", [3.60500,	9.44500, 9.65300, 90.0, 90, 90], "63"],
     "Al2TiO5_new": ["Al2TiO5_new", [3.595,	9.473,	9.677, 90.0, 90, 90], "63"],
@@ -435,8 +431,8 @@ dict_Extinc = {
     "VO2_mono2":"VO2_mono2",
     "rutile": "rutile",
     "SG227": "SG227",
-    "SG141": "SG141",
-    "167":"167","63":"63", "139":"139", "194":"194"
+    "SG141": "SG141","166":"166",
+    "167":"167","63":"63", "139":"139", "194":"194","14":"14","137":"137"
 }
 
 dict_Extinc_inv = {
@@ -457,8 +453,8 @@ dict_Extinc_inv = {
     "VO2_mono2":"VO2_mono2",
     "rutile":"rutile",
     "SG227": "SG227",
-    "SG141": "SG141",
-    "167":"167","63":"63", "139":"139", "194":"194"
+    "SG141": "SG141","166":"166",
+    "167":"167","63":"63", "139":"139", "194":"194","14":"14","137":"137"
 }
 
 # --- -------------- Transforms 3x3 Matrix
