@@ -1763,7 +1763,7 @@ def SimulateLaue(grain, emin, emax, detectorparameters, kf_direction=DEFAULT_TOP
     """
 
     if detectordiameter is None:
-        DETECTORDIAMETER = pixelsize * dim[0]
+        DETECTORDIAMETER = pixelsize * dim[0] * 2
     else:
         DETECTORDIAMETER = detectordiameter
 
@@ -1841,7 +1841,7 @@ def SimulateLaue_full_np(grain, emin, emax, detectorparameters, kf_direction=DEF
     """
 
     if detectordiameter is None:
-        DETECTORDIAMETER = pixelsize * dim[0]
+        DETECTORDIAMETER = pixelsize * dim[0] * 2.0
     else:
         DETECTORDIAMETER = detectordiameter
     # use DEFAULT_TOP_GEOMETRY <=> kf_direction = 'Z>0'
